# *Ceramic*

*Ceramic* is a Python library for turning dataframes into *mosaics* for 
ease of use. For example, you can create a mosaic with *X* and *y* tile columns and 
*training* and *test* tile rows for fitting and testing machine learning models. 